// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"smart-enterprise-management-gateway/param/base"
	pb_v1 "smart-enterprise-management-gateway/pb/v1"
)


type ProjectAddBody struct {
	// 项目名称
	Name string `form:"name" json:"name"`
	// 建设地址
	Location string `form:"location" json:"location"`
	// 安监备案号
	SafetyRecordNo string `form:"safety_record_no" json:"safety_record_no"`
	// 项目类别 1 房屋建筑工程 2 市政工程 3 其他
	Category uint32 `form:"category" json:"category"`
	// 建设性质 1 新建 2 改建 3 扩建
	ConstructType uint32 `form:"construct_type" json:"construct_type"`
	// 资金来源
	InvestType int32 `form:"invest_type" json:"invest_type"`
	// 项目平面图
	ProjectPlan []string `form:"project_plan" json:"project_plan"`
	// 项目所在地行政区域代码
	AreaCode string `form:"area_code" json:"area_code"`
	// 项目规模
	Scale string `form:"scale" json:"scale"`
	// 总投资 万元
	Price float64 `form:"price" json:"price"`
	// 项目简介
	Desc string `form:"desc" json:"desc"`
	// 总面积
	CoveredArea float64 `form:"covered_area" json:"covered_area"`
	// 1 筹备 2 立项 3 在建 4 完工 5 停工
	ProjectStatus uint32 `form:"project_status" json:"project_status"`
	// 经度
	Lon float64 `form:"lon" json:"lon"`
	// 纬度
	Lat float64 `form:"lat" json:"lat"`
	// 项目效果图
	ProjectEffectPic []string `form:"project_effect_pic" json:"project_effect_pic"`
	// 计划开工日期
	StartDay int64 `form:"start_day" json:"start_day"`
	// 计划完工日期
	EndDay               int64    `form:"end_day" json:"end_day"`

}

type ProjectAddRequest struct {
	base.Header
	ProjectAddBody
}

type ProjectAddResponse struct {
	base.Result
}

type ProjectListQuery struct {
	Page int32 `form:"page"`
	Filter string `form:"filter"`
	FilterStatus string `form:"filter_status"`
	PageSize int32 `form:"page_size"`
}

type ProjectListRequest struct {
	base.Header
	ProjectListQuery
}

type ProjectListResponse struct {
	base.Result
	Data pb_v1.ProjectListReply `json:"data"`
}

type ProjectUserListQuery struct {
	Page int32 `form:"page"`
	Filter string `form:"filter"`
}

type ProjectUserListRequest struct {
	base.Header
	ProjectUserListQuery
}

type ProjectUserListResponse struct {
	base.Result
	Data pb_v1.ProjectUserListReply `json:"data"`
}

type EnableProjectUserBody struct {
	Id int64 `form:"id"`
	Enable bool `form:"enable"`
}

type EnableProjectUserRequest struct {
	base.Header
	EnableProjectUserBody
}

type EnableProjectUserResponse struct{
	base.Result
}

type ProjectUserPasswordResetBody struct {
	// 账号id
	Id int64 `form:"id"`
	Password string `form:"password"`
}

type ProjectUserPasswordResetRequest struct{
	base.Header
	ProjectUserPasswordResetBody

}

type ProjectUserPasswordResetResponse struct {
	base.Result
}

type ProjectDistrictRequest struct {
	base.Header
}

type ProjectDistrictResponse struct {
	base.Result
	Data pb_v1.ProjectDistrictReply `json:"data"`
}

type ProjectUpdateBody struct {
	Id                   int64    `json:"id" form:"id"`
	// 项目名称
	Name string `form:"name" json:"name"`
	// 建设地址
	Location string `form:"location" json:"location"`
	// 安监备案号
	SafetyRecordNo string `form:"safety_record_no" json:"safety_record_no"`
	// 项目类别 1 房屋建筑工程 2 市政工程 3 其他
	Category uint32 `form:"category" json:"category"`
	// 建设性质 1 新建 2 改建 3 扩建
	ConstructType uint32 `form:"construct_type" json:"construct_type"`
	// 资金来源
	InvestType int32 `form:"invest_type" json:"invest_type"`
	// 项目平面图
	ProjectPlan []string `form:"project_plan" json:"project_plan"`
	// 项目所在地行政区域代码
	AreaCode string `form:"area_code" json:"area_code"`
	// 项目规模
	Scale string `form:"scale" json:"scale"`
	// 总投资 万元
	Price float64 `form:"price" json:"price"`
	// 项目简介
	Desc string `form:"desc" json:"desc"`
	// 总面积
	CoveredArea float64 `form:"covered_area" json:"covered_area"`
	// 1 筹备 2 立项 3 在建 4 完工 5 停工
	ProjectStatus uint32 `form:"project_status" json:"project_status"`
	// 经度
	Lon float64 `form:"lon" json:"lon"`
	// 纬度
	Lat float64 `form:"lat" json:"lat"`
	// 项目效果图
	ProjectEffectPic []string `form:"project_effect_pic" json:"project_effect_pic"`
	// 计划开工日期
	StartDay int64 `form:"start_day" json:"start_day"`
	// 计划完工日期
	EndDay               int64    `form:"end_day" json:"end_day"`
}

type ProjectUpdateRequest struct {
	base.Header
	ProjectUpdateBody
}

type ProjectUpdateResponse struct {
	base.Result
}

type ProjectInfoPath struct {
	Id int64 `uri:"id"`
}
type ProjectInfoRequest struct {
	base.Header
	ProjectInfoPath
}

type ProjectInfoResponse struct {
	base.Result
	Data pb_v1.ProjectInfoReply `json:"data"`
}

type ProjectDelPath struct {
	Id int64 `uri:"id"`
}

type ProjectDelRequest struct {
	base.Header
	ProjectDelPath
}

type ProjectDelResponse struct {
	base.Result
}

type ProjectFinishPath struct {
	Id int64 `uri:"id"`
}

type ProjectFinishRequest struct {
	base.Header
	ProjectFinishPath
}

type ProjectFinishResponse struct {
	base.Result
}

type AreaCodeListRequest struct {

}

type AreaCodeListResponse struct {
	base.Result
	Data pb_v1.AreaCodeListReply `json:"data"`
}

type AreaCodeLimitRequest struct {

}

type AreaCodeLimitData struct {
	AreaCode string `json:"area_code"`
	CityCode string `json:"city_code"`
}
type AreaCodeLimitResponse struct {
	base.Result
	Data AreaCodeLimitData `json:"data"`
}


